==> vtigercrm-5.3.0p0.tgz: modules/Webmails/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Emails/language/en_us.lang.php,v 1.17 2005/03/28 06:31:38 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Email',
'LBL_MODULE_TITLE'=>'E-mail: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Procurar Email',
'LBL_LIST_FORM_TITLE'=>'Listar Email',
'LBL_NEW_FORM_TITLE'=>'Rastrear Email',

'LBL_LIST_SUBJECT'=>'Assunto',
'LBL_LIST_CONTACT'=>'Contato',
'LBL_LIST_RELATED_TO'=>'Relacionado à',
'LBL_LIST_DATE'=>'Data Envio',
'LBL_LIST_TIME'=>'Hora Envio',
'LBL_MOVE_TO'=>'Mover Para',
'LBL_DELETE'=>'Apagar',
      
'ERR_DELETE_RECORD'=>"Um registro deve ser especificado para apagar a Conta.",
'LBL_DATE_SENT'=>'Data Envio:',
'LBL_SUBJECT'=>'Assunto :',
'LBL_DATE_AND_TIME'=>'Data & Hora Envio:',
'LBL_DATE'=>'Data :',
'LBL_TIME'=>'Hora Envio:',
'LBL_BODY'=>'Corpo:',
'LBL_CONTACT_NAME'=>' Nome Contato: ',
'LBL_EMAIL'=>'E-mail:',
'LBL_COLON'=>':',
'LBL_TO'=>'Para :',
'LBL_CHK_MAIL'=>'Verificar',
'LBL_COMPOSE'=>'Nova',
'LBL_SETTINGS'=>'Configurar',
'LBL_EMAIL_FOLDERS'=>'Pastas Email',
'LBL_INBOX'=>'Caixa Entrada',
'LBL_SENT_MAILS'=>'Enviadas',
'LBL_TRASH'=>'Lixo',
'LBL_JUNK_MAILS'=>'Lixo',
'LBL_TO_LEADS'=>'Para Leads',
'LBL_TO_CONTACTS'=>'Para Contatos',
'LBL_TO_ACCOUNTS'=>'Para Contas',
'LBL_MY_MAILS'=>'Meus E-mails',
'LBL_QUAL_CONTACT'=>'Mensagens Qualificadas (Como Contatos)',
'LBL_MAILS'=>'Mensagens',
'LBL_QUALIFY_BUTTON'=>'Qualificar',
'LBL_REPLY_BUTTON'=>'Responder',
'LBL_FORWARD_BUTTON'=>'Reenviar',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Download Anexos',
'LBL_FROM'=>'De :',
'LBL_CC'=>'cc :',
'LBL_REPLY_TO_SENDER'=>'Responder para Remetente',
'LBL_REPLY_ALL'=>'Responder para Todos',
'LBL_SHOW_HIDDEN'=>'Mostrar Ocultos',
'LBL_EXPUNGE_MAILBOX'=>'Eliminar Caixa Correio',
      
'NTC_REMOVE_INVITEE'=>'Você tem certeza que deseja remover este destinatário?',
'LBL_INVITEE'=>'Destinatários',
      
// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Email em massa',
'LBL_ATTACHMENT'=>'Anexo',
'LBL_UPLOAD'=>'Transferir',
'LBL_FILE_NAME'=>'Nome Arquivo',
'LBL_SEND'=>'Enviar',
      
'LBL_EMAIL_TEMPLATES'=>'Modelo E-mail',
'LBL_TEMPLATE_NAME'=>'Nome Modelo',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_EMAIL_TEMPLATES_LIST'=>'Lista de Modelo Email',
'LBL_EMAIL_INFORMATION'=>'Informação E-mail',
      
      
      
      
//for v4 release added
'LBL_NEW_LEAD'=>'Novo Lead',
'LBL_LEAD_TITLE'=>'Leads',

'LBL_NEW_PRODUCT'=>'Novo Produto',
'LBL_PRODUCT_TITLE'=>'Produtos',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',
'LBL_NEW_ACCOUNT'=>'Nova Conta',
'LBL_ACCOUNT_TITLE'=>'Contas',
      
// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Usuários',
'LBL_NEW_USER'=>'Novo Usuário',
      
// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Email',
//Added for 4GA
'Date & Time Sent'=>'Data & Hora Envio',
'Sales Enity Module'=>'Módulo Vendas',
'Activtiy Type'=>'Tipo Atividade',
'Related To'=>'Relacionado à',
'Assigned To'=>'Responsável',
'Subject'=>'Assunto',
'Attachment'=>'Anexo',
'Description'=>'Descrição',
'Time Start'=>'Hora Início',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
      
'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Por favor verifique o nome do Servidor de Correio...',
'MESSAGE_CHECK_MAIL_ID'=>'Por favor, verifique o ID do Email do Destinatário...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'O Email foi enviado para o seguinte(s) Usuário(s):',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'O Email foi enviado para os seguinte(s) Contato(s) :',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'O ID da Mensagem está incorreto. Por favor verifique o ID da Mensagem...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Por favor adicionar qualquer Usuário(s) ou Contato(s)...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' E-mail(s) enviado(s) com sucesso!',
      
// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Receber E-mail',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'este Contato não deseja receber e-mails.',
'LBL_WEBMAILS_TITLE'=>'WebMails',
'LBL_EMAILS_TITLE'=>'E-mails',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'Erro conectando Servidor de Mensagem!<br> Verifique em Minhas Contas->Lista Servidor Mensagem-> Lista Conta Correio',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'Não é possível conectar ao Servidor de Mensagem. Por favor, verifique os detalhes do Servidor de Mensagem',
'IN_REPLY_TO_THE_MESSAGE' => 'Em resposta à mensagem enviada por',
'LBL_CLICK_HERE' => 'Clique Aqui',
'LBL_GOTO_EMAILS_MODULE' => ' e vá para o Módulo Emails.',
'LBL_NO_EMAILS'=>'Nenhum Email nesta Pasta',
'LBL_MOVE_TO'=>'Mover para...',
'LBL_DEL'=>'Apagar ',
'LABEL_FROM'=>'De',
'LBL_INFO'=>'Informações',
'LABEL_DATE'=>'Data',
'LBL_NO_IFRAMES_SUPPORTED'=>'Não suporta Iframes',
'LBL_EMAIL_ATTACHMENTS'=>'Anexos Email',
'LBL_ALLMAILS'=>'Todos E-mails',
'LBL_TO_USERS'=>'Para Usuários',
'LBL_TO_GROUPS'=>'Para Grupos',
'SUBJECT' => 'Assunto',
'BODY' => 'Corpo',
'TO' => 'Para:',
'CC' => 'CC:',
'BCC' => 'BCC:',
'FROM' => 'De:',
'IN'=>'em',
'ADD_FOLDER' => 'Adicionar Pasta[X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Carregando Imagem',
'LBL_ENABLE_IMAP_SUPPORT' => 'Por favor, habilite o suporte a IMAP no php para executar este Múdulo',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CONFIGURE_MAIL_SETTINGS'=>'Por favor, verifique as configurações do seu email',
'LBL_PLEASE'=>'Por favor',
'LBL_HERE'=>'aqui',

// Added after 5.0.4 GA
'LBL_FULL_EMAIL_VIEW'=>'Visualizar Email Completo',
'LBL_MESSAGE'=>'Mensagem',
'LBL_MESSAGES'=>'Mensagens',

'LBL_NO_ATTACHMENTS'=>'Nenhum arquivo para download',
'LBL_THERE_ARE'=>'Existem ',
'LBL_ATTACHMENTS_TO_CHOOSE'=>' anexo(s) para escolher de',
'LBL_ATTACHMENTS'=>'Anexos',

'LBL_LIST_COUNT'=>'Mostrar',

);
?>

==> vtigercrm-5.4.0.tgz: modules/Webmails/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Emails/language/en_us.lang.php,v 1.17 2005/03/28 06:31:38 rank Exp $
 * Description:  Defines the English language pack for the Webmail.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Email',
'LBL_MODULE_TITLE'=>'E-mail: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Procurar Email',
'LBL_LIST_FORM_TITLE'=>'Listar Email',
'LBL_NEW_FORM_TITLE'=>'Rastrear Email',

'LBL_LIST_SUBJECT'=>'Assunto',
'LBL_LIST_CONTACT'=>'Contato',
'LBL_LIST_RELATED_TO'=>'Relacionado à',
'LBL_LIST_DATE'=>'Data Envio',
'LBL_LIST_TIME'=>'Hora Envio',
'LBL_MOVE_TO'=>'Mover Para',
'LBL_DELETE'=>'Apagar',
      
'ERR_DELETE_RECORD'=>"Um registro deve ser especificado para apagar a Organização.",
'LBL_DATE_SENT'=>'Data Envio:',
'LBL_SUBJECT'=>'Assunto :',
'LBL_DATE_AND_TIME'=>'Data & Hora Envio:',
'LBL_DATE'=>'Data :',
'LBL_TIME'=>'Hora Envio:',
'LBL_BODY'=>'Corpo:',
'LBL_CONTACT_NAME'=>' Nome Contato: ',
'LBL_EMAIL'=>'E-mail:',
'LBL_COLON'=>':',
'LBL_TO'=>'Para :',
'LBL_CHK_MAIL'=>'Verificar',
'LBL_COMPOSE'=>'Nova',
'LBL_SETTINGS'=>'Configurar',
'LBL_EMAIL_FOLDERS'=>'Pastas Email',
'LBL_INBOX'=>'Caixa Entrada',
'LBL_SENT_MAILS'=>'Enviadas',
'LBL_TRASH'=>'Lixo',
'LBL_JUNK_MAILS'=>'Lixo',
'LBL_TO_LEADS'=>'Para Leads',
'LBL_TO_CONTACTS'=>'Para Contatos',
'LBL_TO_ACCOUNTS'=>'Para Organizações',
'LBL_MY_MAILS'=>'Meus E-mails',
'LBL_QUAL_CONTACT'=>'Mensagens Qualificadas (Como Contatos)',
'LBL_MAILS'=>'Mensagens',
'LBL_QUALIFY_BUTTON'=>'Qualificar',
'LBL_REPLY_BUTTON'=>'Responder',
'LBL_FORWARD_BUTTON'=>'Reenviar',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Download Anexos',
'LBL_FROM'=>'De :',
'LBL_CC'=>'cc :',
'LBL_REPLY_TO_SENDER'=>'Responder para Remetente',
'LBL_REPLY_ALL'=>'Responder para Todos',
'LBL_SHOW_HIDDEN'=>'Mostrar Ocultos',
'LBL_EXPUNGE_MAILBOX'=>'Eliminar Caixa Correio',
      
'NTC_REMOVE_INVITEE'=>'Você tem certeza que deseja remover este destinatário?',
'LBL_INVITEE'=>'Destinatários',
      
// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Email em massa',
'LBL_ATTACHMENT'=>'Anexo',
'LBL_UPLOAD'=>'Transferir',
'LBL_FILE_NAME'=>'Nome Arquivo',
'LBL_SEND'=>'Enviar',
      
'LBL_EMAIL_TEMPLATES'=>'Modelo E-mail',
'LBL_TEMPLATE_NAME'=>'Nome Modelo',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_EMAIL_TEMPLATES_LIST'=>'Lista de Modelo Email',
'LBL_EMAIL_INFORMATION'=>'Informação E-mail',
      
      
      
      
//for v4 release added
'LBL_NEW_LEAD'=>'Novo Lead',
'LBL_LEAD_TITLE'=>'Leads',

'LBL_NEW_PRODUCT'=>'Novo Produto',
'LBL_PRODUCT_TITLE'=>'Produtos',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',
'LBL_NEW_ACCOUNT'=>'Nova Organização',
'LBL_ACCOUNT_TITLE'=>'Organizações',
      
// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Usuários',
'LBL_NEW_USER'=>'Novo Usuário',
      
// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Email',
//Added for 4GA
'Date & Time Sent'=>'Data & Hora Envio',
'Sales Enity Module'=>'Módulo Vendas',
'Activtiy Type'=>'Tipo Atividade',
'Related To'=>'Relacionado à',
'Assigned To'=>'Responsável',
'Subject'=>'Assunto',
'Attachment'=>'Anexo',
'Description'=>'Descrição',
'Time Start'=>'Hora Início',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
      
'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Por favor verifique o nome do Servidor de Correio...',
'MESSAGE_CHECK_MAIL_ID'=>'Por favor, verifique o ID do Email do Destinatário...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'O Email foi enviado para o seguinte(s) Usuário(s):',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'O Email foi enviado para os seguinte(s) Contato(s) :',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'O ID da Mensagem está incorreto. Por favor verifique o ID da Mensagem...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Por favor adicionar qualquer Usuário(s) ou Contato(s)...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' E-mail(s) enviado(s) com sucesso!',
      
// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Receber E-mail',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todos',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'Este Contato não deseja receber e-mails.',
'LBL_WEBMAILS_TITLE'=>'WebMails',
'LBL_EMAILS_TITLE'=>'Email',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'Erro conectando Servidor de Mensagem!<br> Verifique em Minhas Organizações->Lista Servidor Mensagem-> Lista Organização Correio',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'Não é possível conectar ao Servidor de Mensagem. Por favor, verifique os detalhes do Servidor de Mensagem',
'IN_REPLY_TO_THE_MESSAGE' => 'Em resposta à mensagem enviada por',
'LBL_CLICK_HERE' => 'Clique Aqui',
'LBL_GOTO_EMAILS_MODULE' => ' e vá para o Módulo Emails.',
'LBL_NO_EMAILS'=>'Nenhum Email nesta Pasta',
'LBL_MOVE_TO'=>'Mover para...',
'LBL_DEL'=>'Apagar ',
'LABEL_FROM'=>'De',
'LBL_INFO'=>'Informações',
'LABEL_DATE'=>'Data',
'LBL_NO_IFRAMES_SUPPORTED'=>'Não suporta Iframes',
'LBL_EMAIL_ATTACHMENTS'=>'Anexos Email',
'LBL_ALLMAILS'=>'Todos E-mails',
'LBL_TO_USERS'=>'Para Usuários',
'LBL_TO_GROUPS'=>'Para Grupos',
'SUBJECT' => 'Assunto',
'BODY' => 'Corpo',
'TO' => 'Para:',
'CC' => 'CC:',
'BCC' => 'BCC:',
'FROM' => 'De:',
'IN'=>'em',
'ADD_FOLDER' => 'Adicionar Pasta[X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Carregando Imagem',
'LBL_ENABLE_IMAP_SUPPORT' => 'Por favor, habilite o suporte a IMAP no php para executar este Múdulo',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CONFIGURE_MAIL_SETTINGS'=>'Por favor, verifique as configurações do seu email',
'LBL_PLEASE'=>'Por favor',
'LBL_HERE'=>'aqui',

// Added after 5.0.4 GA
'LBL_FULL_EMAIL_VIEW'=>'Visualizar Email Completo',
'LBL_MESSAGE'=>'Mensagem',
'LBL_MESSAGES'=>'Mensagens',

'LBL_NO_ATTACHMENTS'=>'Nenhum arquivo para download',
'LBL_THERE_ARE'=>'Existem ',
'LBL_ATTACHMENTS_TO_CHOOSE'=>' anexo(s) para escolher de',
'LBL_ATTACHMENTS'=>'Anexos',

'LBL_LIST_COUNT'=>'Mostrar',

'LBL_INSTEAD_OF_WEBMAILS_USE' => 'Ao invés de Webmails, por favor, clique aqui para usar',
'LBL_PLEASE_CLICK_HERE_TO_GO_TO' => 'Por favor, clique aqui para ir para',
);
?>
